"use strict";

exports.__esModule = true;
exports.takeAction = exports.definition = undefined;

var _sanctuary = require("sanctuary");

var prop = _sanctuary.prop;

var _sanctuaryDef = require("sanctuary-def");

var $ = _interopRequireDefault(_sanctuaryDef).default;

var _define = require("./define");

var definitors = _interopRequireDefault(_define).default;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let def, a, b, takeAction, FN, definition;
({
  def,
  a,
  b
} = definitors($));
"/*** @function takeAction* @param  {Function} defaultAction The default action to execute if nothing matches* @param  {Object} options An object containing functions to execute when the property of the object matches* @param  {String} field A property on the input object to select wich action to take* @param  {Object} item An object to execute an action on, looking at the provided field and searching for it on the actions map* @return {Any} The return value of the selected option executed on the input object* @memberOf Object#* @sig (a -> b) -> StrMap (a -> b) -> String -> Object -> b* @category Logic* @description * Creates a function that takes an object and executes one action on it. * The action is selected looking at the value of the property `field` and searching for it on the map of actions. If no action matches then the default action is executed on the input object* Please note that it only works on objects, so it is intended to execute actions on objects based on one of the object's properties* @example* const options = { admin: u => ({...u, superPowers: true })*                 , user: ({...u, superPowers: false }) *                 };* const defaultAction = x => ({...x, banned: true})* const registerUser = takeAction (defaultAction) (options) ('role')** registerUser ({name:'Daniel', age: 18, role: 'admin' }) // => {name:'Daniel', age: 18, role: 'admin', superPowers: true }* registerUser ({name:'NoBody', age: 18, role:'no-role'}) // => {name:'NoBody', age: 18, role:'no-role', banned: true}*/";

exports.takeAction = takeAction = function takeAction(defaultAction) {
  return actions => field => {
    let p;
    p = prop(field);
    return function (msg) {
      let action;
      action = actions[p(msg)] || defaultAction;
      return action(msg);
    };
  };
};

FN = $.Function([a, b]);
exports.definition = definition = def("sanfu/takeAction")({})([FN, $.StrMap(FN), $.String, $.Object, b])(takeAction);
exports.definition = definition;
exports.takeAction = takeAction;